ProofBuildingError

Enum ProofBuildingError 

pub enum ProofBuildingError {
    InvalidResponse,
    ServerFailure,
    NoSuchName,
    MissingRecord,
    Unauthenticated,
    NoResponseExpected,
}
Possible errors when building queries. Note that there are many possible errors, but only a handful of common ones are captured in the variants here.

Variants



InvalidResponse

The server provided an invalid response.

We failed to parse the server’s response or it contained nonsense that we couldn’t understand.



ServerFailure

The server we are querying gave us a response code of SERVFAIL or FORMERR.

This generally indicates it failed to connect to some DNS server required to resolve our queries or it couldn’t understand the response it got back from such a server.



NoSuchName

The server we are querying gave us a response code of NXDOMAIN on our very first query.

This indicates the name being queried for does not exist.



MissingRecord

The server we are querying gave us a response code of NXDOMAIN.

This indicates the server couldn’t find an answer to one of our queries.



Unauthenticated

The server responded indicating it could not authenticate the response using DNSSEC.

This generally indicates that the data we are querying for was not DNSSEC-signed. It could also indicate that the server we are trying to query using does not validate DNSSEC.



NoResponseExpected

A query was provided when no query was expected.

This indicates a bug in the code driving the proof builder, rather than an issue with the DNS.