pub enum ValidationError {
UnsupportedAlgorithm,
Invalid,
ValidationCountLimited,
}Expand description
An error when validating DNSSEC signatures or other data
Variants
UnsupportedAlgorithm
An algorithm used in signing was not supported.
While data was provided, it couldn’t be authenticated and may be forged.
In cases where signing is mandatory, this can be treated as an error.
Invalid
The provided data was invalid or signatures did not validate.
ValidationCountLimited
We would need to validate more than MAX_PROOF_STEPS sets of RRSigs to validate the
proof we were given.